OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migration en cours. Veuillez attendre que celle-ci se termine",
    "Migration started …" : "Migration démarrée...",
    "Saved" : "Sauvegardé",
    "Not saved" : "Non sauvegardé",
    "Sending…" : "Envoi en cours...",
    "Email sent" : "E-mail envoyé",
    "Private" : "Privé",
    "Local" : "Local",
    "Federated" : "Fédéré",
    "Only synchronize to trusted servers" : "Ne synchroniser qu'avec les serveurs de confiance",
    "Published" : "Publier",
    "Synchronize to trusted servers and the global and public address book" : "Synchronisation avec les serveurs de confiance et le carnet d'adresses mondial et public",
    "Verify" : "Vérifier",
    "Verifying …" : "Vérification en cours...",
    "Unable to change password" : "Impossible de modifier le mot de passe",
    "Very weak password" : "Mot de passe de très faible sécurité",
    "Weak password" : "Mot de passe de faible sécurité",
    "So-so password" : "Mot de passe de sécurité tout juste acceptable",
    "Good password" : "Mot de passe de sécurité suffisante",
    "Strong password" : "Mot de passe de forte sécurité",
    "An error occurred while changing your language. Please reload the page and try again." : "Une erreur est survenue lors du changement de votre langue. Veuillez recharger la page et réessayer.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Une erreur est survenue lors du changement de vos paramètres régionaux. Veuillez recharger la page et réessayer.",
    "Select a profile picture" : "Selectionnez une photo de profil ",
    "Week starts on {fdow}" : "La semaine commence le {fdow}",
    "Groups" : "Groupes",
    "Group list is empty" : "La liste du groupe est vide",
    "Unable to retrieve the group list" : "Impossible de récupérer la liste du groupe",
    "{actor} added you to group {group}" : "{actor} vous a ajouté au groupe {group}",
    "You added {user} to group {group}" : "Vous avez ajouté {user} au groupe {group}",
    "{actor} added {user} to group {group}" : "{actor} a ajouté {user} au groupe {group}",
    "An administrator added you to group {group}" : "Un administrateur vous a ajouté au groupe {group}",
    "An administrator added {user} to group {group}" : "Un administrateur a ajouté {user} au groupe {group}",
    "{actor} removed you from group {group}" : "{actor} vous a retiré du groupe {group}",
    "You removed {user} from group {group}" : "Vous avez retiré {user} du groupe {group}",
    "{actor} removed {user} from group {group}" : "{actor} a retiré {user} du groupe {group}",
    "An administrator removed you from group {group}" : "Un administrateur vous a retiré du groupe {group}",
    "An administrator removed {user} from group {group}" : "Un administrateur a retiré {user} du groupe {group}",
    "Your <strong>group memberships</strong> were modified" : "Vos <strong>adhésions aux groupes</strong> ont été modifiées",
    "{actor} changed your password" : "{actor} a modifié votre mot de passe",
    "You changed your password" : "Vous avez modifié votre mot de passe",
    "Your password was reset by an administrator" : "Votre mot de passe a été réinitialisé par un administrateur",
    "Your password was reset" : "Votre mot de passe a été réinitialisé",
    "{actor} changed your email address" : "{actor} a modifié votre adresse e-mail",
    "You changed your email address" : "Vous avez modifié votre adresse e-mail",
    "Your email address was changed by an administrator" : "Votre adresse e-mail a été modifiée par un administrateur",
    "You created app password \"{token}\"" : "Vous avez créé un mot de passe d'application \"{token}\"",
    "You deleted app password \"{token}\"" : "Vous avez supprimé un mot de passe d'application \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Vous avez renommé le mot de passe d'application \"{token}\" en \"{newToken}\" ",
    "You granted filesystem access to app password \"{token}\"" : "Vous avez accordé au système de fichiers l'accès au mot de passe d'application \"{token}\".",
    "You revoked filesystem access from app password \"{token}\"" : "Vous avez révoqué l'accès au système de fichiers à partir du mot de passe d'application \"{token}\".",
    "Security" : "Sécurité",
    "You successfully logged in using two-factor authentication (%1$s)" : "Vous avez réussi à vous connecter en utilisant l'authentification à deux facteurs (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Une tentative de connexion utilisant l'authentification à deux facteurs a échoué (%1$s)",
    "Remote wipe was started on %1$s" : "Effaçage distant démarré pour%1$s",
    "Remote wipe has finished on %1$s" : "Effaçage distant terminé pour %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Votre <strong>mot de passe</strong> ou <strong>adresse e-mail</strong> a été modifié",
    "Couldn't remove app." : "Impossible de supprimer l'application.",
    "Couldn't update app." : "Impossible de mettre à jour l'application",
    "Wrong password" : "Mot de passe incorrect",
    "No user supplied" : "Aucun utilisateur fourni",
    "Authentication error" : "Erreur d'authentification",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données utilisateur seront perdues.",
    "Wrong admin recovery password. Please check the password and try again." : "Mot de passe administrateur de récupération de données non valable. Veuillez vérifier le mot de passe et essayer à nouveau.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "L'infrastructure d'arrière-plan ne supporte pas la modification de mot de passe, mais la clef de chiffrement de l'utilisateur a été mise à jour.",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL utilise %1$s version (%2$s), qui est une version obsolète. Veuillez mettre à jour votre système d'exploitation, ou des fonctionnalités telles que %3$s ne fonctionneront pas correctement.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Impossible de déterminer si la version TLS de cURL est périmée ou non en raison d’une erreur survenue lors de la demande HTTPS contre https://nextcloud.com. Veuillez consulter le fichier journal de nextcloud pour plus de détails.",
    "Invalid SMTP password." : "Mot de passe SMTP incorrect.",
    "Email setting test" : "Test des paramètres e-mail",
    "Well done, %s!" : "Bien joué, %s !",
    "If you received this email, the email configuration seems to be correct." : "Si vous avez reçu cet e-mail, la configuration de l'adresse e-mail semble être correcte.",
    "Email could not be sent. Check your mail server log" : "L'email n'a pu être envoyé. Vérifiez le journal du serveur de messagerie",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres. (Erreur: %s)",
    "You need to set your user email before being able to send test emails." : "Vous devez définir une adresse e-mail dans vos paramètres personnels avant de pouvoir envoyer des e-mails de test.",
    "Invalid user" : "Utilisateur non valable",
    "Invalid mail address" : "Adresse e-mail non valide",
    "Settings saved" : "Paramètres sauvegardés",
    "Unable to change full name" : "Impossible de modifier le nom complet",
    "Unable to change email address" : "Impossible de modifier l'adresse e-mail",
    "Unable to set invalid phone number" : "Impossible d'enregistrer un n° de téléphone incorrect",
    "Some account data was invalid" : "Certaines données du compte ne sont pas valides",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pour vérifier votre compte Twitter, postez le tweet suivant sur Twitter (veuillez vérifier de le poster sans saut de ligne) :",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pour vérifier votre site web, placez le contenu suivant à la racine de votre site à '.well-known/CloudIdVerificationCode.txt' (veuillez vérifier que le texte complet est en une seule ligne) :",
    "%1$s changed your password on %2$s." : "%1$s a modifié votre mot de passe sur %2$s.",
    "Your password on %s was changed." : "Votre mot de passe sur %s a été modifié.",
    "Your password on %s was reset by an administrator." : "Votre mot de passe sur %s a été réinitialisé par un administrateur.",
    "Your password on %s was reset." : "Votre mot de passe sur %s a été réinitialisé.",
    "Password for %1$s changed on %2$s" : "Mot de passe pour %1$s a été modifié sur %2$s",
    "Password changed for %s" : "Mot de passe modifié pour %s",
    "If you did not request this, please contact an administrator." : "Si vous n'aviez pas effectué cette demande, veuillez contacter un administrateur.",
    "Your email address on %s was changed." : "Votre adresse e-mail sur %s a été modifiée.",
    "Your email address on %s was changed by an administrator." : "Votre adresse e-mail sur %s a été modifiée par un administrateur.",
    "Email address for %1$s changed on %2$s" : "Adresse e-mail pour %1$s a été modifiée sur %2$s",
    "Email address changed for %s" : "Adresse e-mail a été modifiée pour %s",
    "The new email address is %s" : "La nouvelle adresse e-mail est %s",
    "Your %s account was created" : "Votre compte %s a été créé",
    "Welcome aboard" : "Bienvenue à bord",
    "Welcome aboard %s" : "Bienvenue à bord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bienvenue dans votre compte %s, vous pouvez ajouter, protéger et partager vos données.",
    "Your username is: %s" : "Votre nom d'utilisateur est : %s",
    "Set your password" : "Créer votre mot de passe",
    "Go to %s" : "Aller à %s",
    "Install Client" : "Installer le Client",
    "Logged in user must be a subadmin" : "L'utilisateur connecté doit être un sous-administrateur",
    "Apps" : "Apps",
    "Settings" : "Paramètres",
    "Personal" : "Personnel",
    "Administration" : "Administration",
    "Additional settings" : "Paramètres supplémentaires",
    "Groupware" : "Travail collaboratif",
    "Overview" : "Vue d'ensemble",
    "Basic settings" : "Paramètres de base",
    "Sharing" : "Partage",
    "Personal info" : "Informations personnelles",
    "Mobile & desktop" : "Mobile & bureau",
    "Email server" : "Serveur e-mail",
    "Security & setup warnings" : "Avertissements de sécurité & configuration",
    "Background jobs" : "Tâches de fond",
    "Create" : "Créer",
    "Change" : "Modifier",
    "Delete" : "Supprimer",
    "Reshare" : "Repartager",
    "Unlimited" : "Illimité",
    "Verifying" : "Vérification en cours",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Une tâche en arrière-plan qui vérifie les certificats SSL importés par l’utilisateur est en attente. Veuillez vérifier plus tard.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Certains certificats SSL importés par les utilisateurs sont présents et ne sont plus utilisés avec Nextcloud 21. Ils peuvent être importés par l'interface en ligne de commande via la commande \"occ security:certificates:import\". Leurs chemins dans le dossier data sont affichés ci-dessous.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "L'ancien format de chiffrement côté serveur est activé. Nous recommandons de le désactiver.",
    "Nextcloud settings" : "Paramètres Nextcloud",
    "None" : "Aucun",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "L'authentification à deux facteurs peut être forcée pour tous les utilisateurs et des groupes spécifiques. S'ils n'ont pas un fournisseur à deux facteurs configuré, ils ne seront pas capable de s'identifier au système.",
    "Enforce two-factor authentication" : "Imposer l'authentification à deux facteurs",
    "Limit to groups" : "Limiter aux groupes",
    "Enforcement of two-factor authentication can be set for certain groups only." : "L'application de l'authentification à deux facteurs ne peut être définie que pour certains groupes.",
    "Two-factor authentication is enforced for all members of the following groups." : "L'authentification à deux facteurs est forcée pour tous les membre des groupes suivants.",
    "Enforced groups" : "Groupes forcés",
    "Two-factor authentication is not enforced for members of the following groups." : "L'authentification à deux facteurs n'est pas forcée pour les membres des groupes suivants.",
    "Excluded groups" : "Groupes exclus",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Lorsque des groupes sont sélectionnés/exclus, la logique suivante est utilisée pour déterminer si un utilisateur a activé l'authentification double facteur (2FA). Si aucun groupe n'est sélectionné, l'authentification double facteur (2FA) est activé pour tout le monde sauf pour les membres des groupes exclus. Si des groupes sont sélectionnés, l'authentification double facteur (2FA) est activé pour tous les membres de ces groupes. Si un utilisateur est à la fois dans un groupe sélectionné et exclus, c'est le groupe sélectionné qui prime et l'authentification double facteur (2FA) est appliquée.",
    "Save changes" : "Enregistrer les modifications",
    "All" : "Tous",
    "Limit app usage to groups" : "Limiter l'utilisation de l'application aux groupes",
    "No results" : "Aucun résultat",
    "Update to {version}" : "Mise à jour vers {version}",
    "Remove" : "Supprimer",
    "Disable" : "Désactiver",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Cette application n'a pas de version minimum Nextcloud exigée. Ce sera considéré comme une erreur à l'avenir.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Cette application n'a pas de version maximum Nextcloud exigée. Ce sera considéré comme une erreur à l'avenir.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Cette application ne peut être installée à cause de ces dépendances non satisfaites :",
    "View in store" : "Afficher dans le magasin d'application",
    "Visit website" : "Visiter le site web",
    "Report a bug" : "Signaler un bogue",
    "User documentation" : "Documentation utilisateur",
    "Admin documentation" : "Documentation administrateur",
    "Developer documentation" : "Documentation pour développeurs",
    "This app is supported via your current Nextcloud subscription." : "Vous supportez cette application grâce à votre abonnement Nextcloud.",
    "Supported" : "Pris en charge",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les applications mises en avant sont développées par la communauté. Elles proposent des fonctionnalités centrales et sont prêtes pour la production.",
    "Featured" : "Mises en avant",
    "Update to {update}" : "Mise à jour vers {update}",
    "Update all" : "Tout mettre à jour",
    "Results from other categories" : "Résultats d'autres catégories",
    "No apps found for your version" : "Pas d'application trouvée pour votre version",
    "Disable all" : "Tout désactiver",
    "Enable all" : "Tout activer",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n application ayant une mise à jour disponible","%n applications ayant une mise à jour disponible"],
    "Marked for remote wipe" : "Marqué pour l'effaçage distant",
    "Device settings" : "Paramètres de l'appareil",
    "Allow filesystem access" : "Autoriser l'accès au gestionnaire de fichiers",
    "Rename" : "Renommer",
    "Revoke" : "Révoquer",
    "Wipe device" : "Effacer l'appareil",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Révoquer ce jeton peut empêcher l'effacement de votre appareil s'il n'a pas encore démarré l'effacement.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome pour Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Sync client - {os}" : "Client de synchronisation - {os}",
    "This session" : "Cette session",
    "Device" : "Appareil",
    "Last activity" : "Dernière activité",
    "Devices & sessions" : "Appareils & sessions",
    "Web, desktop and mobile clients currently logged in to your account." : "Clients web, applications de bureau et mobiles actuellement connectés avec votre compte.",
    "Do you really want to wipe your data from this device?" : "Voulez-vous vraiment supprimer vos données de cet appareil ?",
    "Confirm wipe" : "Confirmer la supression",
    "Error while creating device token" : "Erreur lors de la création du jeton de l'appareil",
    "Error while updating device token scope" : "Erreur lors de la mise à jour du jeton de l'appareil",
    "Error while updating device token name" : "Erreur lors de la mise à jour du nom du jeton",
    "Error while deleting the token" : "Erreur lors de la suppression du jeton",
    "Error while wiping the device with the token" : "Erreur lors de l'effaçage de l'appareil avec le jeton",
    "App name" : "Nom de l'application",
    "Create new app password" : "Créer un nouveau mot de passe d'application",
    "Use the credentials below to configure your app or device." : "Utilisez les informations d'identification ci-dessous pour configurer votre application ou appareil.",
    "For security reasons this password will only be shown once." : "Pour des raisons de sécurité, ce mot de passe ne sera affiché qu'une seule fois.",
    "Username" : "Nom d'utilisateur",
    "Password" : "Mot de passe",
    "Done" : "Terminé",
    "Show QR code for mobile apps" : "Afficher le QR code pour les applications mobiles",
    "Copied!" : "Copié !",
    "Copy" : "Copier",
    "Could not copy app password. Please copy it manually." : "Impossible de copier le mot de passe de l'application. Merci de le copier manuellement.",
    "Your email address" : "Votre adresse e-mail",
    "No email address set" : "Aucune adresse e-mail configurée",
    "Language" : "Langue",
    "Help translate" : "Aidez à traduire",
    "No language set" : "Aucune langue définie",
    "Add" : "Ajouter",
    "You do not have permissions to see the details of this user" : "Vous n'avez pas les autorisations pour voir le détail de cet utilisateur",
    "Add new password" : "Ajouter un nouveau mot de passe",
    "Add new email address" : "Ajouter une nouvelle adresse e-mail",
    "Set user as admin for" : "Définir en tant qu'administrateur pour",
    "Select user quota" : "Sélectionner le quota de l'utilisateur ",
    "Delete user" : "Supprimer l'utilisateur",
    "Wipe all devices" : "Effacer tous les appareils",
    "Disable user" : "Désactiver l'utilisateur",
    "Enable user" : "Activer l'utilisateur",
    "Resend welcome email" : "Renvoyer l'e-mail de bienvenue",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En cas de perte d'appareil ou si vous quittez un groupe ou une organisation, cette appli supprimera les données de tous les appareils associés à {userid}. Ne fonctionne que si les appareils associés sont connecté à internet.",
    "Remote wipe of devices" : "Vider les appareils à distance",
    "Wipe {userid}'s devices" : "Vider les appareils de {userid}",
    "Cancel" : "Annuler",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Supprime totalement le compte de {userid} et toutes les données associées (fichiers personnels, données de l'application, etc.)",
    "Account deletion" : "Suppression de compte",
    "Delete {userid}'s account" : "Supprimer le compte {userid}",
    "Welcome mail sent!" : "E-mail de bienvenue envoyé !",
    "Edit User" : "Modifier l'utilisateur",
    "Toggle user actions menu" : "Basculer le menu des actions de l'utilisateur",
    "{size} used" : "{size} utilisé",
    "New user" : "Nouvel utilisateur",
    "Will be autogenerated" : "Sera généré automatiquement",
    "Display name" : "Nom à afficher",
    "Email" : "Adresse e-mail",
    "Default language" : "Langue par défaut",
    "Add a new user" : "Ajouter un nouvel utilisateur",
    "Group admin for" : "Administrateur de groupe pour",
    "Quota" : "Quota",
    "User backend" : "Retour utilisateur",
    "Storage location" : "Emplacement du stockage",
    "Last login" : "Dernière connexion",
    "No users in here" : "Aucun utilisateur",
    "Default quota" : "Quota par défaut",
    "Common languages" : "Langues communes",
    "Password change is disabled because the master key is disabled" : "Le changement de mot de passe est désactivé car la clé principale est désactivée",
    "Passwordless authentication requires a secure connection." : "L'authentification sans mot de passe requiert une connexion sécurisée.",
    "Add WebAuthn device" : "Ajouter un appareil WebAuthn",
    "Please authorize your WebAuthn device." : "Veuillez autoriser votre appareil WebAuthn.",
    "Name your device" : "Nom de votre appareil",
    "Adding your device …" : "Ajout de votre appareil…",
    "Server error while trying to add WebAuthn device" : "Erreur du serveur lors de l'ajout de l'appareil WebAuthn ",
    "Server error while trying to complete WebAuthn device registration" : "Erreur du serveur lors de l'enregistrement de l'appareil WebAuthn",
    "Unnamed device" : "Appareil sans nom",
    "Passwordless Authentication" : "Authentification sans mot de passe",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configurer votre compte pour une authentification sans mot de passe suivant le standard FIDO2.",
    "No devices configured." : "Aucun appareil paramétré.",
    "The following devices are configured for your account:" : "Les appareils suivants sont paramétrés pour votre compte :",
    "Your browser does not support WebAuthn." : "Votre navigateur ne prend pas en charge WebAuthn.",
    "Your apps" : "Vos applications",
    "Active apps" : "Applications actives",
    "Disabled apps" : "Applications désactivées",
    "Updates" : "Mises à jour",
    "App bundles" : "Pack d'applications",
    "Featured apps" : "Apps mises en avant",
    "{license}-licensed" : "Sous licence {license}",
    "Details" : "Détails",
    "Changelog" : "Journal des modifications",
    "by {author}\n{license}" : "par {author}\n{license}",
    "Enter group name" : "Saisissez le nom du groupe",
    "Add group" : "Ajouter un groupe",
    "Admins" : "Administrateurs",
    "Disabled users" : "Utilisateurs désactivés",
    "Remove group" : "Supprimer le groupe",
    "Default quota:" : "Quota par défaut :",
    "Select default quota" : "Sélectionner le quota par défaut",
    "Show Languages" : "Afficher les langues",
    "Show last login" : "Afficher la dernière connexion",
    "Show user backend" : "Montrer la source de l'identifiant",
    "Show storage path" : "Afficher le chemin du stockage",
    "Send email to new user" : "Envoyer un e-mail aux utilisateurs créés",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Vous êtes sur le point de supprimer le groupe {group}. Les utilisateurs ne seront PAS supprimés.",
    "Please confirm the group removal " : "Veuillez confirmer la suppression du groupe",
    "Address" : "Adresse",
    "Full name" : "Nom complet",
    "Phone number" : "Numéro de téléphone",
    "Twitter" : "Twitter",
    "Website" : "Site web",
    "Download and enable" : "Télécharger et activer",
    "Enable" : "Activer",
    "Enable untested app" : "Activer les app non-testées",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Cette application n'est pas indiquée comme étant compatible avec votre version de Nextcloud. Si vous continuez vous pourrez toujours installer l'app. Notez cependant qu'elle pourrait ne pas fonctionner comme prévu.",
    "Never" : "Jamais",
    "An error occured during the request. Unable to proceed." : "Une erreur est survenue durant la requête. Impossible de traiter la demande.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'application a été activée mais doit être mise à jour. Vous allez être redirigé vers la page des mises à jour dans 5 secondes.",
    "App update" : "Mise à jour de l'application",
    "Administrator documentation" : "Documentation administrateur",
    "Documentation" : "Documentation",
    "Forum" : "Forum",
    "Login" : "Login",
    "Plain" : "En clair",
    "NT LAN Manager" : "Gestionnaire du réseau NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Voir la documentation",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Il est important d'indiquer un serveur afin de pouvoir envoyer des mails en cas de perte de mot de passe et pour d'autres notifications.",
    "Send mode" : "Mode d'envoi",
    "Encryption" : "Chiffrement",
    "Sendmail mode" : "mode Sendmail",
    "From address" : "Adresse source",
    "Authentication method" : "Méthode d'authentification",
    "Authentication required" : "Authentification requise",
    "Server address" : "Adresse du serveur",
    "Port" : "Port",
    "Credentials" : "Informations d'identification",
    "SMTP Username" : "Nom d'utilisateur SMTP",
    "SMTP Password" : "Mot de passe SMTP",
    "Save" : "Enregistrer",
    "Test email settings" : "Tester les paramètres e-mail",
    "Send email" : "Envoyer un e-mail",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Il est important pour la sécurité et la performance de votre instance que celle-ci soit correctement configurée. Afin de vous aider, votre instance Nextcloud effectue des vérifications automatiques. Pour de plus amples informations, veuillez consulter la documentation liée.",
    "All checks passed." : "Tous les tests ont réussi.",
    "There are some errors regarding your setup." : "Il y a quelques erreurs concernant votre configuration.",
    "There are some warnings regarding your setup." : "Il y a quelques avertissements concernant votre configuration.",
    "Checking for system and security issues." : "Vérification des problèmes de système et de sécurité.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Merci de consulter les <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guides d'installation ↗</a> et de vérifier les erreurs ou avertissements des <a href=\"%2$s\">logs</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Vérifier la sécurité de votre Nextcloud grâce à <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">notre scan de sécurité ↗</a>",
    "Version" : "Version",
    "Two-Factor Authentication" : "Authentification en deux étapes",
    "Server-side encryption" : "Chiffrement côté serveur",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Le chiffrement côté serveur permet de chiffrer les fichiers qui sont téléversés sur ce serveur. Cela implique des limitations comme une performance moindre, donc activez-le seulement si nécessaire.",
    "Enable server-side encryption" : "Activer le chiffrement côté serveur",
    "Please read carefully before activating server-side encryption: " : "Veuillez lire ceci avec attention avant d'activer le chiffrement :",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Une fois le chiffrement activé, les fichiers téléversés sur le serveur à partir de ce moment seront stockés sous forme chiffrée. Il n'est possible de désactiver le chiffrement que si le module utilisé le permet spécifiquement, et que toutes les conditions préalables sont réunies pour ce faire (par exemple la création d'une clef de récupération).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Le chiffrement seul ne garantit pas la sécurité du système. Veuillez consulter la documentation pour plus d'informations à propos du fonction de l'application de chiffrement, et des cas d'utilisations supportés.",
    "Be aware that encryption always increases the file size." : "Veuillez noter que le chiffrement augmente toujours la taille des fichiers.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Il est opportun de sauvegarder régulièrement vos données. Si ces données sont chiffrées, n'oubliez pas de sauvegarder aussi les clés de chiffrement.",
    "This is the final warning: Do you really want to enable encryption?" : "Dernier avertissement : Voulez-vous vraiment activer le chiffrement ?",
    "Enable encryption" : "Activer le chiffrement",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Aucun module de chiffrement n'est chargé. Merci d'activer un module de chiffrement dans le menu des applications.",
    "Select default encryption module:" : "Sélectionnez le module de chiffrement par défaut :",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle. Veuillez activer l'application \"Default Encryption Module\" et exécuter 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle.",
    "Start migration" : "Démarrer la migration",
    "Last job execution ran %s. Something seems wrong." : "Quelque chose s'est mal passé lors de l'exécution de la dernière tâche %s.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Certaines tâches n'ont pas été exécutées depuis %s. Vous pourriez augmenter la fréquence d'exécution.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Certaines tâches n’ont pas été exécutées depuis 1%s. Veuillez envisager de passer à un système cron.",
    "Last job ran %s." : "Dernière tâche exécutée %s.",
    "Background job didn’t run yet!" : "La tâche de fond n'a pas encore tourné!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Afin d'optimiser au mieux la performance de votre instance, il est important de configurer correctement les travaux en arrière-plan. 'Cron' est le paramètre recommandé pour les instances de taille importante. Veuillez vous référer à la documentation Nextcloud pour plus d'informations à ce sujet.",
    "Pick background job setting" : "Définir les paramètres pour la tâche d'arrière-plan",
    "Execute one task with each page loaded." : "Exécute une tâche à chaque chargement de page",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php est enregistré à un service webcron pour exécuter cron.php toutes les 5 minutes par HTTP.",
    "Use system cron service to call the cron.php file every 5 minutes." : "Utiliser le service cron du système pour appeler le fichier cron.php toutes les 5 minutes.",
    "The cron.php needs to be executed by the system user \"%s\"." : "Le cron.php doit être exécuté par l'utilisateur système \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Pour l'exécuter, vous devez avoir l'extension PHP POSIX. Regarder la {linkstart}documentation PHP{linkend} pour plus de détails.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "En tant qu'administrateur, vous pouvez affiner le comportement de partage. Veuillez consulter la documentation pour plus d'informations.",
    "Allow apps to use the Share API" : "Autoriser les applications à utiliser l'API de partage",
    "Set default expiration date for shares" : "Définir une date d'expiration par défaut pour les partages",
    "Enforce expiration date" : "Imposer la date d'expiration",
    "Allow public uploads" : "Autoriser les téléversements publics",
    "Always ask for a password" : "Toujours demander un mot de passe",
    "Enforce password protection" : "Imposer la protection renforcée du mot de passe",
    "Allow resharing" : "Autoriser le repartage",
    "Allow sharing with groups" : "Autoriser le partage avec les groupes",
    "Restrict users to only share with users in their groups" : "N'autoriser les partages qu'entre membres de mêmes groupes",
    "Exclude groups from sharing" : "Empêcher certains groupes de partager",
    "These groups will still be able to receive shares, but not to initiate them." : "Ces groupes ne pourront plus initier de partage, mais ils pourront toujours rejoindre les partages faits par d'autres. ",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Afficher les conditions d'utilisation sur la page publique de téléversement (seulement lorsque la liste des fichiers est masquée).",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ce texte sera affiché sur la page publique de téléversement lorsque la liste des fichiers est masquée.",
    "Default share permissions" : "Autorisations de partage par défaut",
    "Reasons to use Nextcloud in your organization" : "Pourquoi utiliser Nextcloud dans votre organisation ?",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Développé par la {communityopen}communauté Nextcloud{linkclose}, le {githubopen}code source{linkclose} est sous licence {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Aimez notre page Facebook",
    "Follow us on Twitter" : "Suivez-nous sur Twitter",
    "Follow us on Mastodon" : "Suivez-nous sur Mastodon",
    "Check out our blog" : "Découvrez notre blog",
    "Subscribe to our newsletter" : "Abonnez-vous à notre lettre d'information",
    "Profile picture" : "Photo de profil",
    "Upload new" : "Nouvelle depuis votre ordinateur",
    "Select from Files" : "Sélectionner depuis les Fichiers",
    "Remove image" : "Supprimer l'image",
    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 Mo",
    "Picture provided by original account" : "Photo fournie par le compte original",
    "Choose as profile picture" : "Définir comme image de profil",
    "You are a member of the following groups:" : "Vous êtes un membre des groupes suivants :",
    "You are using <strong>%s</strong>" : "Vous utilisez <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Vous utilisez <strong>%1$s</strong> sur <strong>%2$s</strong> (<strong>%3$s%% </strong>)",
    "Your phone number" : "Votre numéro de téléphone",
    "Your postal address" : "Votre adresse postale",
    "It can take up to 24 hours before the account is displayed as verified." : "Cela peut prendre jusqu'à 24 heures avant que le compte soit affiché comme vérifié.",
    "Link https://…" : "Lien https://…",
    "Twitter handle @…" : "Pseudo Twitter @...",
    "Locale" : "Paramètres régionaux",
    "Current password" : "Mot de passe actuel",
    "New password" : "Nouveau mot de passe",
    "Change password" : "Changer de mot de passe",
    "Use a second factor besides your password to increase security for your account." : "Utiliser un second facteur d'authentification en plus de votre mot de passe pour augmenter la sécurité de votre compte.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si vous utilisez des applications tierces pour vous connecter à Nextcloud, assurez-vous de créer et de configurer un mot de passe d'application pour chacune avant d'activer l'authentification à deux facteurs.",
    "Don't synchronize to servers" : "Ne pas synchroniser avec les serveurs",
    "Trusted" : "Approuvé",
    "Public" : "Publique",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "le partage Federated Cloud ou l'installation et la mise à jour d'applications par l'app store",
    "Nextcloud iOS app" : "Application iOS Nextcloud",
    "Nextcloud Android app" : "Application Android Nextcloud",
    "Nextcloud Talk for iOS" : "Nextcloud Talk pour iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk pour Android",
    "Add user in group" : "Ajouter un utilisateur au groupe",
    "Close" : "Fermer",
    "All languages" : "Toutes les langues",
    "Everyone" : "Tout le monde",
    "The app will be downloaded from the app store" : "Cette application va être téléchargée depuis l'app store",
    "Error: This app can not be enabled because it makes the server unstable" : "Erreur : Cette application ne peut pas être activée car cela rend le serveur instable.",
    "mail" : "e-mail",
    "Expire after " : "Expiration après ",
    "days" : "jours",
    "Allow users to share via link" : "Autoriser les utilisateurs à partager par lien",
    "Set default expiration date for link shares" : "Date d'expiration par défaut pour les partages par lien",
    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Activer l'autocomplétion des noms d'utilisateurs dans la fenêtre de partage (Si cette option est désactivée, les noms complets ou les adresses e-mail doivent être indiqués)",
    "Restrict username autocompletion to users within the same groups" : "Limiter la saisie automatique du nom d'utilisateur aux utilisateurs appartenant aux mêmes groupes",
    "No display name set" : "Aucun nom d'affichage configuré",
    "For password reset and notifications" : "Pour la réinitialisation du mot de passe et les notifications"
},
"nplurals=2; plural=(n > 1);");
